# pyBCabsorption

Infers structure of internally mixed black carbon aggregates based on measurements of mixing state, black carbon mass, and light absorption.

## Dependencies

  * numpy
  * scipy
  * matplotlib

## Documentation

http://pyBCabsorption.readthedocs.io/en/latest

## Installation

	pip install pyBCabsorption

Or clone from source and run

	python setup.py install

## Publications

  * [Beeler P., Heinson W.R., and Chakrabarty R.K. (2022) Paper Title. Journal](doi)
